EXPORTS
	??ACRecipientList@@QBEABVTDesC16@@H@Z @ 1 NONAME ; class TDesC16 const & CRecipientList::operator[](int) const
	?AddAttachmentInfoL@CMessageDetailInfo@@QAEXPAVCMessageAttachInfo@@@Z @ 2 NONAME ; void CMessageDetailInfo::AddAttachmentInfoL(class CMessageAttachInfo *)
	?AddAttachmentL@CSendMessageParams@@QAEXPAVCMsvAttachment@@@Z @ 3 NONAME ; void CSendMessageParams::AddAttachmentL(class CMsvAttachment *)
	?AddFromL@CFilterParamInfo@@QAEXABVTDesC16@@@Z @ 4 NONAME ; void CFilterParamInfo::AddFromL(class TDesC16 const &)
	?AddMtmL@CFilterParamInfo@@QAEHABVTDesC16@@@Z @ 5 NONAME ; int CFilterParamInfo::AddMtmL(class TDesC16 const &)
	?AddRecipientL@CMessageDetailInfo@@QAEXABVTDesC16@@K@Z @ 6 NONAME ; void CMessageDetailInfo::AddRecipientL(class TDesC16 const &, unsigned long)
	?AddRecipientL@CSendMessageParams@@QAEXABVTDesC16@@K@Z @ 7 NONAME ; void CSendMessageParams::AddRecipientL(class TDesC16 const &, unsigned long)
	?AppendL@CRecipientList@@QAEXKABVTDesC16@@@Z @ 8 NONAME ; void CRecipientList::AppendL(unsigned long, class TDesC16 const &)
	?AttachFlag@CMessageHeader@@QBEHXZ @ 9 NONAME ; int CMessageHeader::AttachFlag(void) const
	?AttachmentArray@CSendMessageParams@@QAEPBV?$CArrayPtr@VCMsvAttachment@@@@XZ @ 10 NONAME ; class CArrayPtr<class CMsvAttachment> const * CSendMessageParams::AttachmentArray(void)
	?AttachmentInfoArray@CMessageDetailInfo@@QAEPBV?$CArrayPtr@VCMessageAttachInfo@@@@XZ @ 11 NONAME ; class CArrayPtr<class CMessageAttachInfo> const * CMessageDetailInfo::AttachmentInfoArray(void)
	?BodyText@CMessageDetailInfo@@QBE?BVTPtrC16@@XZ @ 12 NONAME ; class TPtrC16 const CMessageDetailInfo::BodyText(void) const
	?BodyText@CSendMessageParams@@QBE?BVTPtrC16@@XZ @ 13 NONAME ; class TPtrC16 const CSendMessageParams::BodyText(void) const
	?Cancel@CMessagingService@@QAEHJ@Z @ 14 NONAME ; int CMessagingService::Cancel(long)
	?CancelNotification@CMessagingService@@QAEHW4TNotificationType@@PAVCMsgCallbackBase@@@Z @ 15 NONAME ; int CMessagingService::CancelNotification(enum TNotificationType, class CMsgCallbackBase *)
	?ChangeStatusL@CMessagingService@@QAEXJW4TMessageStatusFlag@@HPAVCMsgCallbackBase@@@Z @ 16 NONAME ; void CMessagingService::ChangeStatusL(long, enum TMessageStatusFlag, int, class CMsgCallbackBase *)
	?Count@CRecipientList@@QBEHXZ @ 17 NONAME ; int CRecipientList::Count(void) const
	?DeleteMessageL@CMessagingService@@QAEXJPAVCMsgCallbackBase@@@Z @ 18 NONAME ; void CMessagingService::DeleteMessageL(long, class CMsgCallbackBase *)
	?EndDate@CFilterParamInfo@@QBEABVTTime@@XZ @ 19 NONAME ; class TTime const & CFilterParamInfo::EndDate(void) const
	?FileHandle@CMessageAttachInfo@@QBE?AVRFile@@XZ @ 20 NONAME ; class RFile CMessageAttachInfo::FileHandle(void) const
	?Filter@CFilterParamInfo@@QBEHXZ @ 21 NONAME ; int CFilterParamInfo::Filter(void) const
	?From@CFilterParamInfo@@QBEPBVCDesC16Array@@XZ @ 22 NONAME ; class CDesC16Array const * CFilterParamInfo::From(void) const
	?From@CMessageDetailInfo@@QBE?BVTPtrC16@@XZ @ 23 NONAME ; class TPtrC16 const CMessageDetailInfo::From(void) const
	?From@CMessageHeader@@QBE?BVTPtrC16@@XZ @ 24 NONAME ; class TPtrC16 const CMessageHeader::From(void) const
	?GetAttachFlag@CMessageHeader@@QBEXAAH@Z @ 25 NONAME ; void CMessageHeader::GetAttachFlag(int &) const
	?GetIdListL@CMessagingService@@QAEXPAVCFilterParamInfo@@JPAVCMsgCallbackBase@@AAPAVCMsvEntrySelection@@@Z @ 26 NONAME ; void CMessagingService::GetIdListL(class CFilterParamInfo *, long, class CMsgCallbackBase *, class CMsvEntrySelection * &)
	?GetMessageDetailL@CMessagingService@@QAEXJPAVCMsgCallbackBase@@AAPAVCMessageDetailInfo@@@Z @ 27 NONAME ; void CMessagingService::GetMessageDetailL(long, class CMsgCallbackBase *, class CMessageDetailInfo * &)
	?GetMessageId@CMessageHeader@@QBEXAAJ@Z @ 28 NONAME ; void CMessageHeader::GetMessageId(long &) const
	?GetMtmId@CMessageHeader@@QBEXAAVTUid@@@Z @ 29 NONAME ; void CMessageHeader::GetMtmId(class TUid &) const
	?GetNextHeaderL@CMessagingService@@QAEXPAVCFilterParamInfo@@PAVCMsvEntrySelection@@AAHPAVCMsgCallbackBase@@AAPAVCMessageHeader@@@Z @ 30 NONAME ; void CMessagingService::GetNextHeaderL(class CFilterParamInfo *, class CMsvEntrySelection *, int &, class CMsgCallbackBase *, class CMessageHeader * &)
	?GetPriorityFlag@CMessageHeader@@QBEXAAW4TMsvPriority@@@Z @ 31 NONAME ; void CMessageHeader::GetPriorityFlag(enum TMsvPriority &) const
	?GetTime@CMessageHeader@@QBEXAAVTTime@@@Z @ 32 NONAME ; void CMessageHeader::GetTime(class TTime &) const
	?GetUnreadFlag@CMessageHeader@@QBEXAAH@Z @ 33 NONAME ; void CMessageHeader::GetUnreadFlag(int &) const
	?LaunchEditor@CSendMessageParams@@QBEHXZ @ 34 NONAME ; int CSendMessageParams::LaunchEditor(void) const
	?MessageId@CFilterParamInfo@@QBEJXZ @ 35 NONAME ; long CFilterParamInfo::MessageId(void) const
	?MessageId@CMessageDetailInfo@@QBEJXZ @ 36 NONAME ; long CMessageDetailInfo::MessageId(void) const
	?MessageId@CMessageHeader@@QBEJXZ @ 37 NONAME ; long CMessageHeader::MessageId(void) const
	?MessageType@CSendMessageParams@@QBE?AVTUid@@XZ @ 38 NONAME ; class TUid CSendMessageParams::MessageType(void) const
	?MimeType@CMessageAttachInfo@@QBE?BVTPtrC16@@XZ @ 39 NONAME ; class TPtrC16 const CMessageAttachInfo::MimeType(void) const
	?Mtm@CFilterParamInfo@@QBEPBVCDesC16Array@@XZ @ 40 NONAME ; class CDesC16Array const * CFilterParamInfo::Mtm(void) const
	?Mtm@CMessageHeader@@QBE?AVTPtrC16@@XZ @ 41 NONAME ; class TPtrC16 CMessageHeader::Mtm(void) const
	?Name@CMessageAttachInfo@@QBE?BVTPtrC16@@XZ @ 42 NONAME ; class TPtrC16 const CMessageAttachInfo::Name(void) const
	?NewL@CFilterParamInfo@@SAPAV1@XZ @ 43 NONAME ; class CFilterParamInfo * CFilterParamInfo::NewL(void)
	?NewL@CMessageAttachInfo@@SAPAV1@XZ @ 44 NONAME ; class CMessageAttachInfo * CMessageAttachInfo::NewL(void)
	?NewL@CMessageDetailInfo@@SAPAV1@XZ @ 45 NONAME ; class CMessageDetailInfo * CMessageDetailInfo::NewL(void)
	?NewL@CMessageHeader@@SAPAV1@XZ @ 46 NONAME ; class CMessageHeader * CMessageHeader::NewL(void)
	?NewL@CMessagingService@@SAPAV1@XZ @ 47 NONAME ; class CMessagingService * CMessagingService::NewL(void)
	?NewL@CRecipientList@@SAPAV1@XZ @ 48 NONAME ; class CRecipientList * CRecipientList::NewL(void)
	?NewL@CSendMessageParams@@SAPAV1@XZ @ 49 NONAME ; class CSendMessageParams * CSendMessageParams::NewL(void)
	?Priority@CMessageHeader@@QBE?AVTPtrC16@@XZ @ 50 NONAME ; class TPtrC16 CMessageHeader::Priority(void) const
	?RecipientArray@CMessageDetailInfo@@QBEPBVCRecipientList@@XZ @ 51 NONAME ; class CRecipientList const * CMessageDetailInfo::RecipientArray(void) const
	?RecipientArray@CSendMessageParams@@QBEPBVCRecipientList@@XZ @ 52 NONAME ; class CRecipientList const * CSendMessageParams::RecipientArray(void) const
	?RequestNotification@CMessagingService@@QAEHW4TNotificationType@@PAVCMsgCallbackBase@@@Z @ 53 NONAME ; int CMessagingService::RequestNotification(enum TNotificationType, class CMsgCallbackBase *)
	?Reset@CFilterParamInfo@@QAEXXZ @ 54 NONAME ; void CFilterParamInfo::Reset(void)
	?Reset@CRecipientList@@QAEXXZ @ 55 NONAME ; void CRecipientList::Reset(void)
	?SendMessageL@CMessagingService@@QAEXPAVCSendMessageParams@@PAVCMsgCallbackBase@@@Z @ 56 NONAME ; void CMessagingService::SendMessageL(class CSendMessageParams *, class CMsgCallbackBase *)
	?SetAttachFlag@CMessageHeader@@QAEXH@Z @ 57 NONAME ; void CMessageHeader::SetAttachFlag(int)
	?SetBodyTextL@CMessageDetailInfo@@QAEXABVTDesC16@@@Z @ 58 NONAME ; void CMessageDetailInfo::SetBodyTextL(class TDesC16 const &)
	?SetBodyTextL@CSendMessageParams@@QAEXABVTDesC16@@@Z @ 59 NONAME ; void CSendMessageParams::SetBodyTextL(class TDesC16 const &)
	?SetEndDate@CFilterParamInfo@@QAEXABVTTime@@@Z @ 60 NONAME ; void CFilterParamInfo::SetEndDate(class TTime const &)
	?SetFileHandle@CMessageAttachInfo@@QAEXVRFile@@@Z @ 61 NONAME ; void CMessageAttachInfo::SetFileHandle(class RFile)
	?SetFromL@CMessageDetailInfo@@QAEXABVTDesC16@@@Z @ 62 NONAME ; void CMessageDetailInfo::SetFromL(class TDesC16 const &)
	?SetFromL@CMessageHeader@@QAEXABVTDesC16@@@Z @ 63 NONAME ; void CMessageHeader::SetFromL(class TDesC16 const &)
	?SetLaunchEditor@CSendMessageParams@@QAEXH@Z @ 64 NONAME ; void CSendMessageParams::SetLaunchEditor(int)
	?SetMessageId@CMessageDetailInfo@@QAEXJ@Z @ 65 NONAME ; void CMessageDetailInfo::SetMessageId(long)
	?SetMessageId@CMessageHeader@@QAEXJ@Z @ 66 NONAME ; void CMessageHeader::SetMessageId(long)
	?SetMessageIdFilter@CFilterParamInfo@@QAEXJ@Z @ 67 NONAME ; void CFilterParamInfo::SetMessageIdFilter(long)
	?SetMessageTypeL@CSendMessageParams@@QAEHABVTDesC16@@@Z @ 68 NONAME ; int CSendMessageParams::SetMessageTypeL(class TDesC16 const &)
	?SetMimeTypeL@CMessageAttachInfo@@QAEXABVTDesC16@@@Z @ 69 NONAME ; void CMessageAttachInfo::SetMimeTypeL(class TDesC16 const &)
	?SetMtmId@CMessageHeader@@QAEXVTUid@@@Z @ 70 NONAME ; void CMessageHeader::SetMtmId(class TUid)
	?SetNameL@CMessageAttachInfo@@QAEXABVTDesC16@@@Z @ 71 NONAME ; void CMessageAttachInfo::SetNameL(class TDesC16 const &)
	?SetPriorityFlag@CMessageHeader@@QAEXW4TMsvPriority@@@Z @ 72 NONAME ; void CMessageHeader::SetPriorityFlag(enum TMsvPriority)
	?SetSize@CMessageAttachInfo@@QAEXJ@Z @ 73 NONAME ; void CMessageAttachInfo::SetSize(long)
	?SetSortType@CFilterParamInfo@@QAEXW4TMsvSorting@@@Z @ 74 NONAME ; void CFilterParamInfo::SetSortType(enum TMsvSorting)
	?SetStartDateFilter@CFilterParamInfo@@QAEXABVTTime@@@Z @ 75 NONAME ; void CFilterParamInfo::SetStartDateFilter(class TTime const &)
	?SetSubjectL@CFilterParamInfo@@QAEXABVTDesC16@@@Z @ 76 NONAME ; void CFilterParamInfo::SetSubjectL(class TDesC16 const &)
	?SetSubjectL@CMessageHeader@@QAEXABVTDesC16@@@Z @ 77 NONAME ; void CMessageHeader::SetSubjectL(class TDesC16 const &)
	?SetSubjectL@CSendMessageParams@@QAEXABVTDesC16@@@Z @ 78 NONAME ; void CSendMessageParams::SetSubjectL(class TDesC16 const &)
	?SetTemplateId@CSendMessageParams@@QAEXJ@Z @ 79 NONAME ; void CSendMessageParams::SetTemplateId(long)
	?SetTime@CMessageHeader@@QAEXABVTTime@@@Z @ 80 NONAME ; void CMessageHeader::SetTime(class TTime const &)
	?SetUnreadFlag@CMessageHeader@@QAEXH@Z @ 81 NONAME ; void CMessageHeader::SetUnreadFlag(int)
	?Size@CMessageAttachInfo@@QBEJXZ @ 82 NONAME ; long CMessageAttachInfo::Size(void) const
	?SortType@CFilterParamInfo@@QBE?AW4TMsvSorting@@XZ @ 83 NONAME ; enum TMsvSorting CFilterParamInfo::SortType(void) const
	?StartDate@CFilterParamInfo@@QBEABVTTime@@XZ @ 84 NONAME ; class TTime const & CFilterParamInfo::StartDate(void) const
	?Subject@CFilterParamInfo@@QBE?AVTPtrC16@@XZ @ 85 NONAME ; class TPtrC16 CFilterParamInfo::Subject(void) const
	?Subject@CMessageHeader@@QBE?BVTPtrC16@@XZ @ 86 NONAME ; class TPtrC16 const CMessageHeader::Subject(void) const
	?Subject@CSendMessageParams@@QBE?BVTPtrC16@@XZ @ 87 NONAME ; class TPtrC16 const CSendMessageParams::Subject(void) const
	?TemplateId@CSendMessageParams@@QBEJXZ @ 88 NONAME ; long CSendMessageParams::TemplateId(void) const
	?Time@CMessageHeader@@QBEABVTTime@@XZ @ 89 NONAME ; class TTime const & CMessageHeader::Time(void) const
	?Type@CRecipientList@@QBEKH@Z @ 90 NONAME ; unsigned long CRecipientList::Type(int) const
	?UnreadFlag@CMessageHeader@@QBEHXZ @ 91 NONAME ; int CMessageHeader::UnreadFlag(void) const

